dayZones: dayZones

Description Usage Arguments Value

View source: R/helper.R

Description

function to get the total times in zones for a day

Usage

1
dayZones(object)

Arguments

object

S4 object of class 'dayWeek'

Value

A dataframe of times in zones if it can be calcualted, NULL otherwise


theasjblog/tssPlanner_package documentation built on March 8, 2020, 2:36 a.m.