getSessionZones: getSessionZones

Description Usage Arguments Value

View source: R/helper.R

Description

Get the time in zones for a single session

Usage

1
getSessionZones(sessionDetails, userSettings)

Arguments

sessionDetails

(data.frame) The sesisonDetails data frame of a single session

userSettings

(userSettings) The userSettings object

Value

A data.frame of times in zones. NULL if the time in zones cannot be calculated


theasjblog/tssPlanner_package documentation built on March 8, 2020, 2:36 a.m.