Description Usage Arguments Value
Get the time in zones for a single session
1 | getSessionZones(sessionDetails, userSettings)
|
sessionDetails |
(data.frame) The sesisonDetails data frame of a single session |
userSettings |
(userSettings) The userSettings object |
A data.frame of times in zones. NULL if the time in zones cannot be calculated
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.